pub enum SubtableKind<'a> {
Rearrangement(ExtendedStateTable<'a>),
Contextual(ContextualSubtable<'a>),
Ligature(LigatureSubtable<'a>),
NonContextual(LookupU16<'a>),
Insertion(InsertionSubtable<'a>),
}Expand description
The various morx subtable formats.
Variants
Rearrangement(ExtendedStateTable<'a>)
Contextual(ContextualSubtable<'a>)
Ligature(LigatureSubtable<'a>)
NonContextual(LookupU16<'a>)
Insertion(InsertionSubtable<'a>)
Implementations
Sourceimpl<'a> SubtableKind<'a>
impl<'a> SubtableKind<'a>
Sourcepub fn parts(
data: FontData<'a>,
coverage: u32,
) -> Result<SubtableParts, ReadError>
pub fn parts( data: FontData<'a>, coverage: u32, ) -> Result<SubtableParts, ReadError>
Captures the offsets needed to rebuild this subtable kind from the same data with SubtableKind::from_parts.
Sourcepub fn from_parts(
data: FontData<'a>,
parts: &SubtableParts,
) -> Result<Self, ReadError>
pub fn from_parts( data: FontData<'a>, parts: &SubtableParts, ) -> Result<Self, ReadError>
Rebuilds the subtable kind from data and offsets previously
captured with SubtableKind::parts on the same data.